<?php 
    /*
		 _____  ____  _        ______
		|  __ \|  _ \| |      |  ____|
		| |  | | |_) | |      | |__ _ __ __ _ _ __   ___ ___
		| |  | |  _ <| |      |  __| '__/ _` | '_ \ / __/ _ \
		| |__| | |_) | |____  | |  | | | (_| | | | | (_|  __/
		|_____/|____/|______| |_|  |_|  \__,_|_| |_|\___\___|
     * Copyright
     * Classe pour les Modules & SDK FFVE Services
    */    

    class FFVE_TOOLS {
        /**
         * Ajoute un message de log selon le module utilisé.
         *
         * @param string $message  Le message à logger.
         * @param int $priority  La priorité du log.
         * @param int $code  Le code du log.
         */
        static function addLog($message, $priority=1, $code=200) {
            switch (_FFVE_MODULE_VERSION_) {
                case 'PRESTASHOP':
                    PrestaShopLogger::addLog($message, $priority, $code);
                    break;
                case 'WOOCOMMERCE':
                    $logger = new WC_Logger();
                    $logger->add('FFVE', $message);
                    break;
            }
        }

        /**
         * Récupère les informations du module et du serveur.
         *
         * @return string  Les informations du module et du serveur.
         */
        static function moduleInfo() {
            switch (_FFVE_MODULE_VERSION_) {
                case 'PRESTASHOP':
                    $shopVersion = 'Presta ' . _PS_VERSION_;
                    $module_version = 'PRESTA : ' . _FFVE_SERVICES_VERSION_;
                    break;
                case 'WOOCOMMERCE':
                    $shopVersion = defined("WC_VERSION") ? "Woo " . WC_VERSION : "Woo ";
                    $module_version = 'WOO : ' . _FFVE_SERVICES_VERSION_;
                    break;
            }
            $phpVersion = phpversion();
            $info_server = 'Shop ' . $shopVersion . ' / Module ' . $module_version . ' / PHP : ' . $phpVersion;
            return $info_server;
        }

        /**
         * Chiffre une chaîne et stocke la date de chiffrement.
         *
         * @param string $texte  Le texte à chiffrer.
         * @param string $cleSecrete  La clé secrète de chiffrement.
         * @return string  Le texte chiffré en Base64.
         */
        public static function chiffrement($texte, $cleSecrete="") {
            $ffve_settings = new FFVE_SETTINGS();
            $cleSecrete = $ffve_settings->getServer() . $ffve_settings->getUser() . '==FFVESERVICES==';
            $dateChiffrement = date('Y-m-d H:i:s');
            $donneesAChiffrer = array(
                'valeur' => $texte,
                'date' => $dateChiffrement
            );
            $iv = openssl_random_pseudo_bytes(16);
            $donneesChiffrees = openssl_encrypt(json_encode($donneesAChiffrer), 'aes-256-cbc', $cleSecrete, 0, $iv);
            $donneesChiffreesBase64 = base64_encode($iv . $donneesChiffrees);
            return $donneesChiffreesBase64;
        }

        /**
         * Déchiffre une chaîne et vérifie la date.
         *
         * @param string $donneesChiffreesBase64  Les données chiffrées en Base64.
         * @param string $cleSecrete  La clé secrète de déchiffrement.
         * @param int $delaiMax  Le délai maximum en heures pour la validité du chiffrement.
         * @return string|false  Le texte déchiffré ou false en cas d'erreur.
         */
        public static function dechiffrement($donneesChiffreesBase64, $cleSecrete="", $delaiMax = 24) {
            $ffve_settings = new FFVE_SETTINGS();
            $cleSecrete = $ffve_settings->getServer() . $ffve_settings->getUser() . '==FFVESERVICES==';
            $donneesChiffrees = base64_decode($donneesChiffreesBase64);
            $iv = substr($donneesChiffrees, 0, 16);
            $donneesDechiffrees = openssl_decrypt(substr($donneesChiffrees, 16), 'aes-256-cbc', $cleSecrete, 0, $iv);
            if ($donneesDechiffrees === false) {
                if (_FFVE_SERVICES_DEBUG_)
					error_log("Erreur : Échec du déchiffrement.");
                return false;
            }
            $donneesAChiffrer = json_decode($donneesDechiffrees, true);
            if (!$donneesAChiffrer) {
                if (_FFVE_SERVICES_DEBUG_)
					error_log("Erreur : Échec du décodage JSON.");
                return false;
            }
            $dateChiffrement = date_create_from_format('Y-m-d H:i:s', $donneesAChiffrer['date']);
            $dateActuelle = new DateTime();
            $difference = $dateActuelle->diff($dateChiffrement);
            if ($difference->h <= $delaiMax) {
                return $donneesAChiffrer['valeur'];
            } else {
				if (_FFVE_SERVICES_DEBUG_)
					error_log("Erreur : Date de chiffrement dépassée de plus de 8 heures.");
                return false;
            }
        }
    } 

