<?php
class FFVE_UPDATE {
    const UPDATE_URL = 'https://api.ffveservices.com/wp-json/dbl-ffve/plugins/';
    private $plugin_slug;
    private $current_version;

    public function __construct($plugin_slug, $current_version) {
        $this->plugin_slug = $plugin_slug;
        $this->current_version = $current_version;
    }

    public function check_for_update($transient) {
        // URL pour vérifier les mises à jour
        $remote_url = self::UPDATE_URL . 'prestashop-ffve-plugin?slug=' . $this->plugin_slug . '&version=' . $this->current_version;
        $response = $this->makeApiRequest($remote_url);
        if (!$response || !isset($response->new_version)) {
            return $transient;
        }
        if (version_compare($this->current_version, $response->new_version, '<')) {
            $transient->response[$this->plugin_slug] = (object) array(
                'slug'        => $this->plugin_slug,
                'new_version' => $response->new_version,
                'url'         => self::UPDATE_URL . 'prestashop-ffve-plugin-info',  // URL pour plus d'infos sur la mise à jour
                'package'     => $response->package,
            );
        }

        return $transient;
    }

    public function applyUpdate($plugin_url) {
        $zip_file = $this->downloadUpdate($plugin_url);
        if ($zip_file) {
            return $this->installUpdate($zip_file);
        }
        return false;
    }

    private function makeApiRequest($url) {
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        $response = curl_exec($ch);
        curl_close($ch);
        return json_decode($response);
    }

    private function downloadUpdate($plugin_url) {
        $tmp_dir = _FFVE_TMP_DIR_;
        if (!is_dir($tmp_dir)) {
            mkdir($tmp_dir, 0755, true);
        }
        $zip_file = $tmp_dir . 'update-ffveservices.zip';
        $fp = fopen($zip_file, 'w+');
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_POST, 1);
        curl_setopt($ch, CURLOPT_URL, $plugin_url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
        curl_setopt($ch, CURLOPT_FILE, $fp);
        curl_setopt($ch, CURLOPT_TIMEOUT, 50);
        curl_exec($ch);
        curl_close($ch);
        fclose($fp);
        return $zip_file;
    }

    private function installUpdate($zip_file) {
        $zip = new ZipArchive;
        if ($zip->open($zip_file) === TRUE) {
            $zip->extractTo(_PS_MODULE_DIR_);
            $zip->close();
            // Supprimer le fichier zip après extraction
            unlink($zip_file);
            return true;
        } else {
            return false;
        }
    }
}
