<?php
	class AdminFFVEExportController extends ModuleAdminController
	{
		public function __construct()
		{
			$this->bootstrap = true;
			parent::__construct();
		}
		public function renderList()
		{
			// Check if the export button is clicked
			if (Tools::isSubmit('exportFFVE')) {
				// Handle the export logic here
				$this->export_ffve_products();
			}
			
			// Generate the export URL
			$exportUrl = $this->context->link->getAdminLink('AdminFFVEExport', true, array('exportFFVE' => '1'));
			
			// Generate the AJAX URL and token
			$ajaxUrl = $this->context->link->getAdminLink('AdminFFVEExport');
			$ajaxToken = Tools::getAdminTokenLite('AdminFFVEExport');
			
			// Assign variables to Smarty
			$this->context->smarty->assign(array(
			'exportUrl' => $exportUrl,
			'ajaxUrl' => $ajaxUrl,
			'ajaxToken' => $ajaxToken
			));
			
			
			// Fetch the template
			$return = $this->context->smarty->fetch(_PS_MODULE_DIR_ . '/ffveservices/views/templates/admin/export.tpl');
			return $return;
		}
		public function ajaxProcessUploadFfveProducts() {
			// Définir le chemin vers le dossier temporaire
			$temp_dir = _FFVE_DIR . 'export-ffve-services/';
			// Créer le dossier temporaire s'il n'existe pas
			if (!file_exists($temp_dir)) {
				error_log("create dir $temp_dir");
				$res = @mkdir($temp_dir);
				if (!$res){
					$result = ['success'=>false,'message'=>'Impossible de créer : ' . $temp_dir];
					die(Tools::jsonEncode($result));
				}
			}
			// Générer un nom de fichier aléatoire
			$random_file_name = 'FFVE-SERVICES-Export-' . uniqid() . '.csv';
			// Définir le chemin complet du fichier temporaire
			$file_path = $temp_dir.$random_file_name;
			$res = $this->export_ffve_products($file_path);
			$ffve_settings = new FFVE_SETTINGS();
			$ffve_api = new FFVE_API($ffve_settings->getServer(), $ffve_settings->getUser(), $ffve_settings->getPassword() );
			$result=$ffve_api->uploadProducts($file_path);	
			// print json_encode($result);
			
			die(Tools::jsonEncode($result));
			
			
		}		
		
		public function cleanTextExport($txt) {
	$txt = strip_tags($txt, '<ul><li><br><strong>');
	$search=["\n","\r"];
	$txt=str_replace($search, '||', $txt);
	$txt=str_replace(",", '##', $txt);
	return $txt;
		
	}
		
		// Function to handle the export logic
		public function export_ffve_products($file=NULL) {
			// Fetch product IDs from your export table
			$productIds = Db::getInstance()->executeS('
			SELECT id_product
			FROM '._DB_PREFIX_.'ffveservices_export
			');
			if (!$productIds) {
				// No products found in the export table
				return;
			}
			// Prepare a list of product details
			$productDetails = array(); 
			$FFVESettings = new FFVE_SETTINGS();
			$voucherCode = $FFVESettings->getCouponCode();
			foreach ($productIds as $prod) {
				$id_lang = $this->context->language->id;
				// Get the product in the specific language
				$product = new Product((int)$prod['id_product'], false, $id_lang);
				
				if (!Validate::isLoadedObject($product)  || !$product->active ) {
					// Le produit n'existe pas ou pas en ligne, passer à l'itération suivante
					continue;
				} 
				
				$productPrice= $product->getPrice(true, null, 6);	
				// Get the discounted price for the product
				// $discountedPrice = Product::getPriceStatic($product->id,true, null, 6, null, true,true,1,false,null,$cart->id);
				$img = $product->getCover($product->id);
				// Get the main product image URL in the first language
				
				if ($img && isset($img['id_image'])) {
					// Get the main product image URL in the first language
					$imagePath = $this->context->link->getImageLink($product->link_rewrite, (int)$img['id_image'], 'large_default');
					} else {
					// Si l'image n'existe pas, vous pouvez définir un chemin d'image par défaut ou prendre une autre action
					$imagePath = ''; // Remplacez par le chemin de votre image par défaut
				}
				
				// Get the product URL in the first language
				$productUrl = $this->context->link->getProductLink($product, null, null, null, $this->context->language->id);
				
				// Get the product descriptions
        $short_description = strip_tags($product->description_short);
        $long_description = strip_tags($product->description);
				
				
				$categories = Product::getProductCategories($product->id);

				$categoryNames = [];
				$categoryUrls = [];

				// Loop through all the categories and build the category names and URLs
				foreach ($categories as $categoryId) {
					$category = new Category($categoryId, $id_lang);
					$categoryNames[] = str_replace('||','', $this->cleanTextExport( $category->name) );
					$categoryUrls[] = $this->context->link->getCategoryLink($categoryId, $category->link_rewrite, $id_lang);
				}

				// Join the category names and URLs with double pipes '||'
				$categoryNameList = implode('||', $categoryNames);
				$categoryUrlList = implode('||', $categoryUrls);
				
				
				$productDetails[] = array(
				'id_product' => $product->id,
				'name' => $this->cleanTextExport($product->name),
				'price' => $productPrice,
				// 'discountedPrice' => $discountedPrice,
				'image_url' => $imagePath, // Main product image URL in the first language
				'product_url' => $productUrl, // Product URL in the first language
				'category_name' => $categoryNameList, // All category names separated by '||'
				'category_url' => $categoryUrlList, // All category URLs separated by '||'
				'short_description' => $this->cleanTextExport( $short_description), 
				'long_description' =>  $this->cleanTextExport( $long_description) 
				);
			}
			if (!$file){
				header('Content-Type: text/csv');
				header('Content-Disposition: attachment; filename="FFVE-SERVICES-Export-'. date('YmdHis') .'.csv"');
				$columns = array_keys(reset($productDetails)); // Get the keys from the first element
				echo implode(',', $columns) . "\n";
				// Output product details
				foreach ($productDetails as $productDetail) {
					echo '"' . implode('","', $productDetail) . '"' . "\n";
				}
				exit;
				}else{
				// Sortie sur fichier $file
				// Ouverture du fichier en écriture
				$output = fopen($file, 'w');
				// Vérification de l'ouverture du fichier
				if ($output === false) {
					// Gérer l'erreur d'ouverture du fichier
					return false;
				}
				// Sortie des colonnes CSV
				if (!empty($productDetails)) {
					$columns = array_keys(reset($productDetails));
					fputcsv($output, $columns);
					// Sortie des détails des produits
					foreach ($productDetails as $productDetail) {
						fputcsv($output, $productDetail);
					}
				}
				// Fermeture du fichier
				fclose($output);
				return true;
			}
		}
	}							